@@ -14,6 +14,7 @@ CURRENT_TIME = "ct"
 COOK_END_TIME = "sce"
 COOK_ID = "csid"
 GRILL_END_TIME = "sge"
+UNKOWN_VAR = "as"
 
 
 # receiving parameters
@@ -21,3 +22,4 @@ PROBE_PIT = "pt"
 PROBE_1 = "t1"
 PROBE_2 = "t2"
 PROBE_3 = "t3"
+FAN_SPEED = "dc"
